import { dataSource } from "../../../data-source";
import { inspectionPointResult } from "../../../entity/unit/inspection/inspectionPointResult";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class InspectionPointResultService {
  /**
   * @description get all inspectionPointResult types
   * @returns {Promise<Array<inspectionPointResult>>}
   */
  static async getAll(): Promise<Array<inspectionPointResult>> {
    return await dataSource
      .getRepository(inspectionPointResult)
      .createQueryBuilder("inspectionPointResult")
      .orderBy("type", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPointResult", err);
      });
  }

  /**
   * @description get inspectionPointResult by id
   * @returns {Promise<inspectionPointResult>}
   */
  static async getById(id: string): Promise<inspectionPointResult> {
    return await dataSource
      .getRepository(inspectionPointResult)
      .createQueryBuilder("inspectionPointResult")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPointResult", err);
      });
  }
}
